==> ansys_mechanical_stubs-0.1.1.tar.gz: ansys_mechanical_stubs-0.1.1/src/ansys/mechanical/stubs/v241/Ansys/Mechanical/DataModel/ConstructionLines/__init__.py <==
"""ConstructionLines subpackage."""
from enum import Enum
import typing

class PlaneType(Enum):
    """
    
                Enumeration for the possible edge vertex types that can be represented.
            
    """

    pass

class PointType(Enum):
    """
    
                Enumeration for the possible edge vertex types that can be represented.
            
    """

    pass

class ConstructionLineHelper(object):
    """
    
                Helper to perform queries and modifications against a ConstructionLine instance.
            
    """

    @classmethod
    def GetEdgeVerticesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", edgeVertexIdCollection: "System.Collections.Generic.IEnumerable[System.Int32]") -> "System.Collections.Generic.IList[System.Object]":
        """
        GetEdgeVerticesById method.
        """
        pass

    @classmethod
    def GetEdgesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", edgeIdCollection: "System.Collections.Generic.IEnumerable[System.Int32]") -> "System.Collections.Generic.IList[System.Object]":
        """
        GetEdgesById method.
        """
        pass

    @classmethod
    def GetPlanesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", planeIdCollection: "System.Collections.Generic.IEnumerable[System.Int32]") -> "System.Collections.Generic.IList[System.Object]":
        """
        GetPlanesById method.
        """
        pass

    @classmethod
    def GetEdgesUsingPoint(cls, point: "Ansys.Mechanical.DataModel.ConstructionLines.Point") -> "System.Collections.Generic.IList[System.Object]":
        """
        
                Get a list of IEdge that use the given Point.
            
        """
        pass

    @classmethod
    def GetContainedEdges(cls, plane: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> "System.Collections.Generic.IList[System.Object]":
        """
        
                Get all the edges that have both start and end edge vertices in the given plane.
            
        """
        pass

    @classmethod
    def GetRelatedEdges(cls, plane: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> "System.Collections.Generic.IList[System.Object]":
        """
        
                Get all the edges that have only edge vertex in the given plane.
            
        """
        pass

    @classmethod
    def ExportToXML(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", xmlFilePath: "System.String") -> "System.Void":
        """
        
                 Collect all the edges and edge vertices, then export them as global points to an XML file.
             
        """
        pass

    @classmethod
    def ClearExistingDataAndImportFromXML(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", xmlFilePath: "System.String") -> "System.Collections.Generic.IList[System.Object]":
        """
        
                 Import global points and connecting edges from an XML file.
             
        """
        pass


class Plane(object):
    """
    
                A 2D sketching planes in a ConstructionLine instance.
            
    """

    @property
    def Type(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.PlaneType"]:
        """
        Type property.
        """
        return None

    @property
    def Definition(self) -> typing.Optional["System.Object"]:
        """
        Definition property.
        """
        return None

    @property
    def Origin(self) -> typing.Optional["Ansys.ACT.Core.Math.Point3D"]:
        """
        
                The global location of this plane's origin.
            
        """
        return None

    @property
    def PrimaryAxisDirection(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The orientation of the plane's primary (X) axis orientation.
            
        """
        return None

    @property
    def SecondaryAxisDirection(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The orientation of the plane's secondary (Y) axis orientation.
            
        """
        return None

    @property
    def Normal(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The plane's normal vector (Z axis orientation) orientation.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional["System.UInt32"]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional["System.Boolean"]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None

    def Equivalent(self, other: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> "System.Boolean":
        """
        
                Checks to see if another plane is equivalent to this one.
            
        """
        pass


class Point(object):
    """
    
                A point in a ConstructionLine instance, may have an associated edge vertex.
            
    """

    @property
    def Type(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.PointType"]:
        """
        Type property.
        """
        return None

    @property
    def Definition(self) -> typing.Optional["System.Object"]:
        """
        Definition property.
        """
        return None

    @property
    def Location(self) -> typing.Optional["Ansys.ACT.Core.Math.Point3D"]:
        """
        
                Get the global location of this point.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional["System.UInt32"]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional["System.Boolean"]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None

    def Equivalent(self, other: "Ansys.Mechanical.DataModel.ConstructionLines.Point") -> "System.Boolean":
        """
        
                Checks to see if another point is equivalent to this one.
            
        """
        pass


import ansys.mechanical.stubs.v241.Ansys.Mechanical.DataModel.ConstructionLines.Edges as Edges

==> ansys_mechanical_stubs-0.1.2.tar.gz: ansys_mechanical_stubs-0.1.2/src/ansys/mechanical/stubs/v241/Ansys/Mechanical/DataModel/ConstructionLines/__init__.py <==
"""ConstructionLines module."""
from enum import Enum
import typing

class PlaneType(Enum):
    """
    
                Enumeration for the possible edge vertex types that can be represented.
            
    """

    pass

class PointType(Enum):
    """
    
                Enumeration for the possible edge vertex types that can be represented.
            
    """

    pass

class ConstructionLineHelper(object):
    """
    
                Helper to perform queries and modifications against a ConstructionLine instance.
            
    """

    @classmethod
    def GetEdgeVerticesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", edgeVertexIdCollection: typing.Iterable[int]) -> list[typing.Any]:
        """
        GetEdgeVerticesById method.
        """
        pass

    @classmethod
    def GetEdgesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", edgeIdCollection: typing.Iterable[int]) -> list[typing.Any]:
        """
        GetEdgesById method.
        """
        pass

    @classmethod
    def GetPlanesById(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", planeIdCollection: typing.Iterable[int]) -> list[typing.Any]:
        """
        GetPlanesById method.
        """
        pass

    @classmethod
    def GetEdgesUsingPoint(cls, point: "Ansys.Mechanical.DataModel.ConstructionLines.Point") -> list[typing.Any]:
        """
        
                Get a list of IEdge that use the given Point.
            
        """
        pass

    @classmethod
    def GetContainedEdges(cls, plane: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> list[typing.Any]:
        """
        
                Get all the edges that have both start and end edge vertices in the given plane.
            
        """
        pass

    @classmethod
    def GetRelatedEdges(cls, plane: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> list[typing.Any]:
        """
        
                Get all the edges that have only edge vertex in the given plane.
            
        """
        pass

    @classmethod
    def ExportToXML(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", xmlFilePath: str) -> None:
        """
        
                 Collect all the edges and edge vertices, then export them as global points to an XML file.
             
        """
        pass

    @classmethod
    def ClearExistingDataAndImportFromXML(cls, constructionLine: "Ansys.ACT.Automation.Mechanical.ConstructionLines.ConstructionLine", xmlFilePath: str) -> list[typing.Any]:
        """
        
                 Import global points and connecting edges from an XML file.
             
        """
        pass


class Plane(object):
    """
    
                A 2D sketching planes in a ConstructionLine instance.
            
    """

    @property
    def Type(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.PlaneType"]:
        """
        Type property.
        """
        return None

    @property
    def Definition(self) -> typing.Optional[typing.Any]:
        """
        Definition property.
        """
        return None

    @property
    def Origin(self) -> typing.Optional["Ansys.ACT.Core.Math.Point3D"]:
        """
        
                The global location of this plane's origin.
            
        """
        return None

    @property
    def PrimaryAxisDirection(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The orientation of the plane's primary (X) axis orientation.
            
        """
        return None

    @property
    def SecondaryAxisDirection(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The orientation of the plane's secondary (Y) axis orientation.
            
        """
        return None

    @property
    def Normal(self) -> typing.Optional["Ansys.ACT.Core.Math.Vector3D"]:
        """
        
                The plane's normal vector (Z axis orientation) orientation.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional[int]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional[bool]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None

    def Equivalent(self, other: "Ansys.Mechanical.DataModel.ConstructionLines.Plane") -> bool:
        """
        
                Checks to see if another plane is equivalent to this one.
            
        """
        pass


class Point(object):
    """
    
                A point in a ConstructionLine instance, may have an associated edge vertex.
            
    """

    @property
    def Type(self) -> typing.Optional["Ansys.Mechanical.DataModel.ConstructionLines.PointType"]:
        """
        Type property.
        """
        return None

    @property
    def Definition(self) -> typing.Optional[typing.Any]:
        """
        Definition property.
        """
        return None

    @property
    def Location(self) -> typing.Optional["Ansys.ACT.Core.Math.Point3D"]:
        """
        
                Get the global location of this point.
            
        """
        return None

    @property
    def ObjectId(self) -> typing.Optional[int]:
        """
        
                Get the ID of the represented entity.
            
        """
        return None

    @property
    def IsRepresentation(self) -> typing.Optional[bool]:
        """
        
                Check to see if there is a valid entity that this instance represents.
            
        """
        return None

    def Equivalent(self, other: "Ansys.Mechanical.DataModel.ConstructionLines.Point") -> bool:
        """
        
                Checks to see if another point is equivalent to this one.
            
        """
        pass


import ansys.mechanical.stubs.v241.Ansys.Mechanical.DataModel.ConstructionLines.Edges as Edges
